@@ -1,5 +1,6 @@
 # Text::Aligner - Align text in columns
 package Text::Aligner;
+
 use strict;
 use warnings;
 
@@ -8,7 +9,7 @@ use 5.008;
 BEGIN    {
     use Exporter ();
     use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION     = '0.11';
+    $VERSION     = '0.13';
     @ISA         = qw (Exporter);
     @EXPORT      = qw ();
     @EXPORT_OK   = qw ( align);
@@ -32,7 +33,7 @@ sub align ($@) {
 
 ### class Text::Aligner
 
-sub _new { # internal creator
+sub _new { # internal constructor
     my $class = shift;
     my ( $width, $pos) = @_; # both method-or-coderef (this is very general)
     bless {
@@ -43,7 +44,7 @@ sub _new { # internal creator
     }, $class;
 }
 
-# create an aligner
+# Construct an aligner
 sub new {
     my ( $class, $spec) = @_;
     $spec ||= 0; # left alignment is default
@@ -123,6 +124,11 @@ sub _forget {
     $al;
 }
 
+sub _spaces {
+    my ($repeat_count) = @_;
+    return (($repeat_count > 0) ? (' ' x $repeat_count) : '');
+}
+
 # justify a string.  a string is aligned within the aligner's field, and
 # filled with blanks or cut to size, as appropriate.  a string that has
 # been allocated will never be trimmed (that is the point of allocation).
@@ -135,7 +141,7 @@ sub _justify {
     my ( $l_pad, $r_pad) = $al->_padding( $str);
     substr( $str, 0, -$l_pad) = '' if $l_pad < 0; # trim if negative
     substr( $str, $r_pad) = '' if $r_pad < 0; # ... both ends
-    join $str, ' ' x $l_pad, ' ' x $r_pad; # pad if positive
+    return _spaces($l_pad) . $str . _spaces($r_pad); # pad if positive
 }
 
 # return two numbers that indicate how many blanks are needed on each side
@@ -303,11 +309,11 @@ Text::Aligner
 
 =head1 VERSION
 
-version 0.11
+version 0.13
 
 =head1 SYNOPSIS
 
-  use Text::Aligner qw( align);
+  use Text::Aligner qw( align );
 
   # Print the words "just a test!" right-justified each on a line:
 
@@ -439,7 +445,7 @@ For internal use.
 
 =head1 BUGS
 
-  None known as of realease, but...
+None known as of release, but...
 
 =head1 AUTHOR
 
@@ -450,7 +456,11 @@ For internal use.
 
 Copyright (c) 2002 Anno Siegel. All rights reserved.
 This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
+it and/or modify it under the terms of the ISC license.
+
+(This program had been licensed under the same terms as Perl itself up to
+version 1.118 released on 2011, and was relicensed by permission of its
+originator).
 
 The full text of the license can be found in the
 LICENSE file included with this module.
@@ -459,7 +469,7 @@ LICENSE file included with this module.
 
 perl(1)
 
-Text::Table
+L<Text::Table> .
 
 =head1 AUTHOR
 
@@ -467,9 +477,10 @@ Shlomi Fish <shlomif@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2002 by Anno Siegel.
+This software is Copyright (c) 2002 by Anno Siegel.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 =cut
